@@ -1,6 +1,6 @@
 from .password_hash import password_hash, PasswordHashAlgorithm
 from .rfc2617 import digest_client, digest_server
-from .dbuser import DBUser as BaseDBUser
+from .dbuser import BaseDBUser
 from .signed_token_jwt import SignedToken, SignedTokenExpiredError, SignedTokenImmatureError, \
         SignedTokenUnacceptedAlgorithmError, SignedTokenSignatureVerificationError
 from .token_box import TokenBox
